@@ -1,11 +1,9 @@
 package Mixin::Event::Dispatch::Event;
-{
-  $Mixin::Event::Dispatch::Event::VERSION = '1.004';
-}
+$Mixin::Event::Dispatch::Event::VERSION = '1.005';
 use strict;
 use warnings;
+
 use List::UtilsBy ();
-use Try::Tiny;
 use Scalar::Util qw(reftype);
 
 use constant DEBUG => $ENV{MIXIN_EVENT_DISPATCH_DEBUG};
@@ -18,7 +16,7 @@ Mixin::Event::Dispatch::Event - an event object
 
 =head1 VERSION
 
-version 1.004
+Version 1.005
 
 =head1 SYNOPSIS
 
@@ -56,7 +54,9 @@ object if we were invoked within an existing handler
 =back
 
 We're assuming that time is of the essence,
-hence the peculiar implementation.
+hence the peculiar implementation. Also note that this
+constructor is rarely called in practice -
+L<Mixin::Event::Dispatch> uses bless directly.
 
 Returns $self.
 
@@ -157,7 +157,7 @@ Returns $self.
 sub dispatch {
 	my $self = shift;
 	$self->debug_print("Dispatch with [@_]") if DEBUG;
-	# Support pre-5.14 Perl versions. The only reason for not using
+	# Support pre-5.14 Perl versions. The main reason for not using
 	# Try::Tiny here is performance; 10k events/sec with Try::Tiny on
 	# an underpowered system, vs. 30k+ with plain eval.
 	eval {
@@ -184,9 +184,10 @@ sub dispatch {
 
 =head2 play
 
-Continue the current event. Semantincs are subject to change
-so avoid this and consider L</defer> instead. Currently does
-nothing anyway.
+Continue the current event. Do not use.
+
+Semantics are subject to change so avoid this and consider
+L</defer> instead. Currently does nothing anyway.
 
 Returns $self.
 
@@ -288,8 +289,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
